/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections.Generic;
using System.Text;
using SheerCMS.Internals;
using System.Web.UI;

namespace SheerCMS
{
    public class BreadcrumbControl : CMSBaseControl
    {
        private string i_dividerImageUrl = string.Empty;
        private string i_dividerString = string.Empty;

        /// <summary>
        /// Gets and sets the string of characters used as the divider between elements of the breadcrumb list.
        /// </summary>
        public string DividerString
        {
            get { return i_dividerString; }
            set { i_dividerString = value; }
        }

        /// <summary>
        /// Gets and sets the url of the image used as the divider between the elements of the breadcrumb list.
        /// If this url is not set, the divider string is used instead.
        /// </summary>
        public string DividerImageUrl
        {
            get { return i_dividerImageUrl; }
            set { i_dividerImageUrl = value; }
        }
	

        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("<div id=\"");
            else
                writer.Write("<span id=\"");

            writer.Write(ID);
            writer.Write("\" class=\"");

            if (!(CssClass == string.Empty || CssClass == null))
            {
                writer.Write(" ");
                writer.Write(CssClass);
            }

            if (!(ToolTip == string.Empty || ToolTip == null))
            {
                writer.Write("\" title=\"");
                writer.Write(ToolTip);
            }

            writer.Write("\" >");
        }


        protected override void RenderContents(HtmlTextWriter writer)
        {
            PageDefinition[] pages = null;
            PageDefinition page = null;
            int pageId;

            try
            {
                pageId = int.Parse(this.Page.Request.QueryString["id"]);
            }
            catch
            {
                pageId = 0;
            }

            pages = PageManager.Instance.GetPagePath(pageId);

            if (pages.Length > 0)
            {
                for (int i = 0; i < pages.Length - 1; i++)
                {
                    page = pages[i];
                    writer.Write("<a href=\"");

                    if (CMSGlobalSettings.FriendlyURL)
                        writer.Write(page.FriendlyFileName);
                    else
                        writer.Write(this.Page.ResolveUrl("~/" + page.Template + ".aspx?id=" + page.ID.ToString()));

                    if (page.PageSummary != string.Empty)
                    {
                        writer.Write("\" title=\"");
                        writer.Write(page.PageSummary);
                    }

                    writer.Write("\" >");
                    writer.Write(page.Title);
                    writer.Write("</a>");

                    if (!(i_dividerImageUrl == string.Empty &&
                        i_dividerString == string.Empty))
                    {
                        writer.Write("<span>");
                        if (i_dividerString == string.Empty)
                        {
                            writer.Write("<img src=\"");
                            writer.Write(i_dividerImageUrl);
                            writer.Write("\" alt=\"\" >");
                        }
                        else
                            writer.Write(i_dividerString);
                        writer.Write("</span>");
                    }
                }

                writer.Write("<span>");
                writer.Write(pages[pages.Length - 1].Title);
                writer.Write("</span>");
            }
            
        }


        public override void RenderEndTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("</div>");
            else
                writer.Write("</span>");
        }
    }
}
