/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using SheerCMS.Internals;

namespace SheerCMS
{
    public abstract class CMSBasePage : System.Web.UI.Page
    {
        private int i_id = -1;

        /// <summary>
        /// Gets the page id.
        /// </summary>
        public int PageId
        {
            get { return i_id; }
        }

        protected override void OnPreInit(EventArgs e)
        {
            string fileName = Request.Url.LocalPath;
            fileName = fileName.Substring(fileName.LastIndexOf('/') + 1, fileName.LastIndexOf('.') - (fileName.LastIndexOf('/')+1));

            PageDefinition content;
            if (this.Page.Request.QueryString["pre"] != "1")
            {
                string id = this.Page.Request.QueryString["id"];

                if (id == string.Empty || id == null)
                {
                    content = PageManager.Instance[PageManager.Instance.DefaultPageId];

                    string url;
                    if (CMSGlobalSettings.FriendlyURL)
                        url = content.FriendlyFileName;
                    else
                        url = content.Template + ".aspx?id=" + content.ID.ToString();

                    Response.Redirect(url, true);

                }
                else
                    content = PageManager.Instance[int.Parse(id)];

                if (content.PageTitle == string.Empty)
                    this.Page.Title = content.Title;
                else
                    this.Page.Title = content.PageTitle;

                if (fileName != content.Template)
                {
                    string url = Request.Url.ToString().ToLower().Replace(fileName.ToLower(), content.Template);

                    Response.Redirect(url, true);
                }

                if (id == string.Empty || id == null)
                    i_id = PageManager.Instance.DefaultPageId;
                else
                    i_id = int.Parse(id);
            }
        
            base.OnPreInit(e);
        }

        protected override void OnLoad(EventArgs e)
        {
            PageDefinition content;

            if (i_id == -1)
            {
                string id = this.Page.Request.QueryString["id"];

                if (id == string.Empty || id == null)
                    i_id = PageManager.Instance.DefaultPageId;
                else
                    i_id = int.Parse(id);
            }

            if (i_id != -1)
            {
                content = PageManager.Instance[i_id];

                if (CMSGlobalSettings.SummaryAsDescription)
                {
                    HtmlMeta description = new HtmlMeta();
                    description.Name = "description";
                    description.Content = content.PageSummary;
                    Header.Controls.Add(description);
                }
            }
            base.OnLoad(e);
        }
    }
}
