/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using SheerCMS.Internals;


namespace SheerCMS
{
    public class ContentControl : WebControl
    {
        private string i_text = string.Empty;
        private int i_sectionId = -1;

        /// <summary>
        /// Gets and sets the text to be displayed in the content control.
        /// This is displayed if the SectionId value has not been set.
        /// If neither this or the SectionID properties are set the content of the specified page id is displayed.
        /// </summary>
        public string Text
        {
            get { return i_text; }
            set { i_text = value; }
        }

        /// <summary>
        /// Gets and sets the id of the section to be displayed in the content control.
        /// If neither this or the Text properties are set the content of the specified page id is displayed.
        /// </summary>
        public int SectionId
        {
            get { return i_sectionId; }
            set { i_sectionId = value; }
        }


        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            writer.Write("<div id=\"");
            writer.Write(ID);

            if (!(CssClass == string.Empty || CssClass == null))
            {
                writer.Write("\" class=\"");
                writer.Write(CssClass);
            }

            if (!(ToolTip == string.Empty || ToolTip == null))
            {
                writer.Write("\" title=\"");
                writer.Write(ToolTip);
            }

            writer.Write("\" >");
        }

        protected override void RenderContents(HtmlTextWriter writer)
        {
            SectionDefinition content;


            if (i_sectionId == -1)
            {
                if (i_text == string.Empty)
                {
                    if (this.Page.Request.QueryString["pre"] == "1")
                        writer.Write(this.Page.Session["preview"].ToString());
                    else
                    {
                        string id = this.Page.Request.QueryString["id"];

                        if (id == string.Empty || id == null)
                            i_sectionId = PageManager.Instance.DefaultPageId;
                        else
                            i_sectionId = int.Parse(id);

                        content = PageManager.Instance[i_sectionId];

                        writer.Write(content.Contents);
                    }
                }
                else
                    writer.Write(i_text);
            }
            else
            {
                content = SectionManager.Instance[i_sectionId];
                writer.Write(content.Contents);
            }
            
        }

        public override void RenderEndTag(HtmlTextWriter writer)
        {
            writer.Write("</div>");
        }

    }
}

