/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using SheerCMS.Internals;

namespace SheerCMS
{
    public class GuestBookControl : CMSBaseControl
    {

        private TextBox i_nameText = null;
        private TextBox i_emailText = null;
        private TextBox i_messageText = null;
        private Button i_saveButton = null;
        private HtmlGenericControl i_messageListArea = null;
        private HtmlGenericControl i_controlListArea = null;

        private bool i_messagesAtTop = true;

        /// <summary>
        /// Gets and sets a value that defines if the GuestBook messages should be rendered 
        /// above, if true, or below, if false, the GuestBook entry part of the control.
        /// </summary>
        public bool MessagesAtTop
        {
            get { return i_messagesAtTop; }
            set { i_messagesAtTop = value; }
        }


        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("<div id=\"");
            else
                writer.Write("<span id=\"");

            writer.Write(ID);

            if (!(CssClass == string.Empty || CssClass == null))
            {
                writer.Write("\" class=\"");
                writer.Write(CssClass);
            }

            if (!(ToolTip == string.Empty || ToolTip == null))
            {
                writer.Write("\" title=\"");
                writer.Write(ToolTip);
            }

            writer.Write("\" >");
        }

        public override void RenderEndTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("</div>");
            else
                writer.Write("</span>");
        }

        protected override void OnInit(EventArgs e)
        {
            i_messageListArea = new HtmlGenericControl();
            i_messageListArea.TagName = "div";
            i_messageListArea.Attributes.Add("class", "guest-message-area");
            i_messageListArea.ID = "guest_message_area";

            i_controlListArea = new HtmlGenericControl();
            i_controlListArea.TagName = "div";
            i_controlListArea.Attributes.Add("class", "guest-control-area");
            i_controlListArea.ID = "guest_control_area";

            ValidationSummary valSummary = new ValidationSummary();
            valSummary.CssClass = "error-text";
            valSummary.DisplayMode = ValidationSummaryDisplayMode.BulletList;
            valSummary.ID = "guest_val_summary";

            i_nameText = new TextBox();
            i_nameText.ID = "guest_name_text";
            i_nameText.CssClass = "guest-name-text";

            Label nameLabel = new Label();
            nameLabel.Text = "Name:";
            nameLabel.AssociatedControlID = "guest_name_text";

            RequiredFieldValidator nameVal = new RequiredFieldValidator();
            nameVal.ID = "guest_name_val";
            nameVal.ErrorMessage = "Please provide a valid name.";
            nameVal.Display = ValidatorDisplay.None;
            nameVal.ControlToValidate = "guest_name_text";

            Literal nameBreak = new Literal();
            nameBreak.Text = "<br />";

            i_emailText = new TextBox();
            i_emailText.ID = "guest_email_text";
            i_emailText.CssClass = "guest-email-text";

            Label emailLabel = new Label();
            emailLabel.Text = "Email Address:";
            emailLabel.AssociatedControlID = "guest_email_text";

            RequiredFieldValidator emailReqVal = new RequiredFieldValidator();
            emailReqVal.ID = "guest_email_req_val";
            emailReqVal.ErrorMessage = "Please provide a valid email address.";
            emailReqVal.Display = ValidatorDisplay.None;
            emailReqVal.ControlToValidate = "guest_email_text";

            RegularExpressionValidator emailVal = new RegularExpressionValidator();
            emailVal.ID = "guest_email_val";
            emailVal.ErrorMessage = "Please provide a valid email address.";
            emailVal.Display = ValidatorDisplay.None;
            emailVal.ControlToValidate = "guest_email_text";
            emailVal.ValidationExpression = @"^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$";

            Literal emailBreak = new Literal();
            emailBreak.Text = "<br />";

            i_messageText = new TextBox();
            i_messageText.TextMode = TextBoxMode.MultiLine;
            i_messageText.ID = "guest_message_text";
            i_messageText.CssClass = "guest-message-text";

            RequiredFieldValidator messageVal = new RequiredFieldValidator();
            messageVal.ID = "guest_message_val";
            messageVal.ErrorMessage = "Please provide a valid message.";
            messageVal.Display = ValidatorDisplay.None;
            messageVal.ControlToValidate = "guest_message_text";

            Literal messageBreak = new Literal();
            messageBreak.Text = "<br />";

            Label messageLabel = new Label();
            messageLabel.Text = "Message:";
            messageLabel.AssociatedControlID = "guest_message_text";

            Literal buttonBreak = new Literal();
            buttonBreak.Text = "<br />";

            i_saveButton = new Button();
            i_saveButton.Text = "Save";
            i_saveButton.ToolTip = "Save";
            i_saveButton.ID = "guest_save_button";
            i_saveButton.CssClass = "guest-save-button";
            i_saveButton.CommandName = "save";
            i_saveButton.Click += new EventHandler(saveButton_Click);

            i_controlListArea.Controls.Add(valSummary);
            i_controlListArea.Controls.Add(nameLabel);
            i_controlListArea.Controls.Add(nameVal);
            i_controlListArea.Controls.Add(i_nameText);
            i_controlListArea.Controls.Add(nameBreak);
            i_controlListArea.Controls.Add(emailLabel);
            i_controlListArea.Controls.Add(emailVal);
            i_controlListArea.Controls.Add(emailReqVal);
            i_controlListArea.Controls.Add(i_emailText);
            i_controlListArea.Controls.Add(emailBreak);
            i_controlListArea.Controls.Add(messageLabel);
            i_controlListArea.Controls.Add(messageVal);
            i_controlListArea.Controls.Add(messageBreak);
            i_controlListArea.Controls.Add(i_messageText);
            i_controlListArea.Controls.Add(buttonBreak);
            i_controlListArea.Controls.Add(i_saveButton);

            if (i_messagesAtTop)
                this.Controls.Add(i_messageListArea);

            this.Controls.Add(i_controlListArea);

            if (!i_messagesAtTop)
                this.Controls.Add(i_messageListArea);

            base.OnInit(e);
        }

        protected override void OnPreRender(EventArgs e)
        {
            string entryBasicHtml = "<div class=\"guest-message\"><div class=\"guest-message-author\">{0}</div><div class=\"guest-message-date\">{1}</div><div class=\"guest-message-content\">{2}</div></div>";
            Literal entryHTML;

            i_messageListArea.Controls.Clear();

            foreach (GuestBookEntry entry in GuestBookManager.Instance)
            {
                entryHTML = new Literal();
                entryHTML.Text = string.Format(entryBasicHtml, entry.Author, entry.Date.ToShortDateString(), entry.Contents);
                i_messageListArea.Controls.Add(entryHTML);
            }
            
            base.OnPreRender(e);
        }


        private void saveButton_Click(object sender, EventArgs e)
        {
            if (Page.IsValid)
            {
                lock (GuestBookManager.Instance)
                {
                    GuestBookEntry entry = new GuestBookEntry();
                    entry.ID = GuestBookManager.Instance.GetNextMessageId();
                    entry.Author = this.Page.Server.HtmlEncode(i_nameText.Text);
                    entry.Email = this.Page.Server.HtmlEncode(i_emailText.Text);
                    entry.Contents = this.Page.Server.HtmlEncode(i_messageText.Text);

                    GuestBookManager.Instance.Add(entry.ID, entry);
                    GuestBookManager.Instance.UpdateContent();

                    i_nameText.Text = string.Empty;
                    i_emailText.Text = string.Empty;
                    i_messageText.Text = string.Empty;
                }
            }
        }
    }
}
