/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections.Generic;
using System.Configuration;
using System.Xml;
using System.Collections;

namespace SheerCMS.Internals
{
    public class GuestBookManager : IEnumerable
    {
        #region Static Code
        private static GuestBookManager i_instance = null;

        static GuestBookManager()
        {
            if (i_instance == null)
            {
                i_instance = new GuestBookManager();
            }
        }

        public static GuestBookManager Instance
        {
            get { return i_instance; }
        }
        #endregion

        private SortedDictionary<int, GuestBookEntry> i_data = new SortedDictionary<int, GuestBookEntry>();
        private int i_maxKeyValue=0;


        internal GuestBookManager()
        {
            LoadMessageLists();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public int GetNextMessageId()
        {
            return i_maxKeyValue+1;
        }

        /// <summary>
        /// 
        /// </summary>
        public void UpdateContent()
        {
            XmlDocument doc = new XmlDocument();
            doc.Load(ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content.xml");

            XmlNode node = doc.SelectSingleNode("content/guestbook/entries");

            if (node != null)
            {
                node.RemoveAll();
                foreach (GuestBookEntry entry in i_data.Values)
                {
                    node.AppendChild(CreateXmlNodeFromEntry(entry, doc));
                }
            }

            doc.Save(ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content.xml");
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        /// <param name="value"></param>
        public void Add(int key, GuestBookEntry value)
        {
            if (i_maxKeyValue < key)
                i_maxKeyValue = key;

            i_data.Add(key, value);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        public void Remove(int key)
        {
            GuestBookEntry definition = i_data[key];
            i_data.Remove(key);
        }

        /// <summary>
        /// 
        /// </summary>
        public int Count
        {
            get { return i_data.Count; }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public GuestBookEntry this[int key]
        {
            get
            {
                return i_data[key];
            }
        }

        #region IEnumerable Members
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public IEnumerator GetEnumerator()
        {
            return i_data.Values.GetEnumerator();
        }

        #endregion


        private XmlNode CreateXmlNodeFromEntry(GuestBookEntry entry, XmlDocument doc)
        {
            XmlElement node = doc.CreateElement("entry");
            XmlAttribute attribute;

            attribute = doc.CreateAttribute("id");
            attribute.InnerText = entry.ID.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("author");
            attribute.InnerText = entry.Author;
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("date");
            attribute.InnerText = entry.Date.ToShortDateString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("email");
            attribute.InnerText = entry.Email;
            node.Attributes.Append(attribute);

            node.AppendChild(doc.CreateCDataSection(entry.Contents));

            return node;
        }

        private void LoadMessageLists()
        {
            XmlDocument doc = new XmlDocument();
            doc.Load(ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content.xml");

            XmlNodeList nodes = doc.SelectNodes("content/guestbook/entries/entry");
            foreach (XmlNode node in nodes)
            {
                GuestBookEntry entry = new GuestBookEntry(node);
                this.Add(entry.ID, entry);
            }
        }
    }
}
