/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using System.Xml;

namespace SheerCMS.Internals
{
    public class ListEntryManager : IEnumerable
    {
        private int i_id = 0;
        private string i_title = string.Empty;
        private string i_description = string.Empty;
        private SortedDictionary<int, ListEntry> i_data = new SortedDictionary<int, ListEntry>();
        private int i_maxKeyValue=0;

        /// <summary>
        /// 
        /// </summary>
        public ListEntryManager() { }

        internal ListEntryManager(XmlNode node)
        {
            if (node.Name == "list")
            {
                if (node.Attributes["id"].InnerText != string.Empty)
                    i_id = int.Parse(node.Attributes["id"].InnerText);

                i_title = node.Attributes["title"].InnerText;

                if (node.Attributes["description"] != null)
                    i_description = node.Attributes["description"].InnerText;

                CreateListEntries(node);
            }
            else
                throw new Exception();//TODO: Add correct Exception message
        }

        /// <summary>
        /// 
        /// </summary>
        public int ID
        {
            get { return i_id; }
            set { i_id = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public string Title
        {
            get { return i_title; }
            set { i_title = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public string Description
        {
            get { return i_description; }
            set { i_description = value; }
        }

        public void Add(ListEntry value)
        {
            i_maxKeyValue++;
            i_data.Add(i_maxKeyValue, value);
            value.ID = i_maxKeyValue;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        /// <param name="value"></param>
        public void Add(int key, ListEntry value)
        {
            if (i_maxKeyValue < key)
                i_maxKeyValue = key;

            i_data.Add(key, value);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        public void Remove(int key)
        {
            if (i_data.ContainsKey(key))
                i_data.Remove(key);
        }

        /// <summary>
        /// 
        /// </summary>
        public int Count
        {
            get { return i_data.Count; }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public ListEntry this[int key]
        {
            get
            {
                return i_data[key];
            }
        }

        #region IEnumerable Members
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public IEnumerator GetEnumerator()
        {
            return i_data.Values.GetEnumerator();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public ListEntry[] GetListEntries()
        {
            ListEntry[] array = new ListEntry[i_data.Count];
            i_data.Values.CopyTo(array, 0);
            return array;
        }
        #endregion

        internal XmlNode CreateXmlNodeFromList(XmlDocument doc)
        {
            XmlElement node = doc.CreateElement("list");
            XmlElement itemsNode = doc.CreateElement("items");
            XmlAttribute attribute;

            attribute = doc.CreateAttribute("id");
            attribute.InnerText = this.ID.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("title");
            attribute.InnerText = this.Title;
            node.Attributes.Append(attribute);

            foreach (ListEntry enty in i_data.Values)
            {
                itemsNode.AppendChild(CreateXmlNodeFromEntry(enty, doc));
            }
            node.AppendChild(itemsNode);

            return node;
        }


        private XmlNode CreateXmlNodeFromEntry(ListEntry entry, XmlDocument doc)
        {
            XmlElement node = doc.CreateElement("item");
            XmlAttribute attribute;

            attribute = doc.CreateAttribute("id");
            attribute.InnerText = entry.ID.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("title");
            attribute.InnerText = entry.Title;
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("date");
            attribute.InnerText = entry.Date.ToShortDateString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("link");
            attribute.InnerText = entry.Link;
            node.Attributes.Append(attribute);

            node.AppendChild(doc.CreateCDataSection(entry.Contents));

            return node;
        }

        private void CreateListEntries(XmlNode node)
        {
            XmlNodeList nodes = node.SelectNodes("items/item");
            foreach (XmlNode itemNode in nodes)
            {
                ListEntry entry = new ListEntry(itemNode);
                this.Add(entry.ID, entry);
            }
        }
    }
}
