/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections.Generic;
using System.Xml;

namespace SheerCMS.Internals
{
    /// <summary>
    /// 
    /// </summary>
    public class PageDefinition : SectionDefinition, IComparable<PageDefinition>
    {
        private string i_friendlyFileName = string.Empty;
        private string i_pageTitle = string.Empty;
        private string i_pageSummary = string.Empty;
        private int i_parentId = 0;
        private int i_menuList = 0;
        private int i_menuOrder = 9999;
        private string i_template = string.Empty;
        private List<PageDefinition> i_children = new List<PageDefinition>();

        /// <summary>
        /// 
        /// </summary>
        public PageDefinition() { }

        internal PageDefinition(XmlNode node) : base(node)
        {
            if (node.Name == "page")
            {
                if (node.Attributes["pageTitle"]!= null && node.Attributes["pageTitle"].InnerText != string.Empty)
                    i_pageTitle = node.Attributes["pageTitle"].InnerText;

                if (node.Attributes["pageSummary"] != null && node.Attributes["pageSummary"].InnerText != string.Empty)
                    i_pageSummary = node.Attributes["pageSummary"].InnerText; 

                if (node.Attributes["parentid"].InnerText != string.Empty)
                    i_parentId = int.Parse(node.Attributes["parentid"].InnerText);

                if (node.Attributes["menuOrder"].InnerText != string.Empty)
                    i_menuOrder = int.Parse(node.Attributes["menuOrder"].InnerText);

                if (node.Attributes["menuList"].InnerText != string.Empty)
                    i_menuList = int.Parse(node.Attributes["menuList"].InnerText);

                i_template = node.Attributes["template"].InnerText;
            }
            else
                throw new Exception();//TODO: Add correct Exception message
        }

        /// <summary>
        /// 
        /// </summary>
        public string PageTitle
        {
            get { return i_pageTitle; }
            set { i_pageTitle = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public string FriendlyFileName
        {
            get
            {
                if (i_friendlyFileName == string.Empty)
                {
                    string fileName = GenerateFriendlyFilePath();

                    i_friendlyFileName = fileName + ".aspx";
                }
                return i_friendlyFileName;
            }
        }

        /// <summary>
        /// 
        /// </summary>
        public string PageSummary
        {
            get { return i_pageSummary; }
            set { i_pageSummary = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public int ParentID
        {
            get { return i_parentId; }
            set 
            {
                if (i_parentId != value)
                {
                    if (i_parentId == 0)
                        PageManager.Instance.RemovePageFromRootPageList(this);
                    else
                        PageManager.Instance[i_parentId].RemoveChild(this);

                    if (value == 0)
                        PageManager.Instance.AddPageToRootPageList(this);
                    else
                        PageManager.Instance[value].AddChild(this);

                    i_parentId = value;
                    i_friendlyFileName = string.Empty;
                }
            }
        }
        
        /// <summary>
        /// 
        /// </summary>
        public string Template
        {
            get { return i_template; }
            set { i_template = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public int MenuOrder
        {
            get { return i_menuOrder; }
            set { i_menuOrder = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public int MenuList
        {
            get { return i_menuList; }
            set 
            {
                if (i_menuList != value)
                {
                    if (i_menuList == 0 && value == 1)
                        PageManager.Instance.AddPageToRootPageList(this);
                    else if (i_menuList == 1 && value == 0)
                    {
                        if (i_parentId == 0)
                            PageManager.Instance.RemovePageFromRootPageList(this);
                        else
                            PageManager.Instance[i_parentId].RemoveChild(this);
                    }
                    i_menuList = value;
                    i_friendlyFileName = string.Empty;
                }
            }
        }

        /// <summary>
        /// 
        /// </summary>
        public PageDefinition[] Children
        {
            get 
            {
                PageDefinition[] children = i_children.ToArray();
                Array.Sort<PageDefinition>(children);
                return children; 
            }
        }


        internal void AddChild(PageDefinition child)
        {
            if (!i_children.Contains(child))
                i_children.Add(child);
        }

        internal void RemoveChild(PageDefinition child)
        {
            if (i_children.Contains(child))
                i_children.Remove(child);
        }

        #region IComparable<PageDefinition> Members
        /// <summary>
        /// 
        /// </summary>
        /// <param name="other"></param>
        /// <returns></returns>
        public int CompareTo(PageDefinition other)
        {
            return MenuOrder-other.MenuOrder;
        }

        #endregion

        private string GenerateFriendlyFilePath()
        {
            return CMSGlobalSettings.BaseFolder + GenerateFriendlyFilePathElement(this) + GenerateFriendlyName(Title);
        }

        private string GenerateFriendlyFilePathElement(PageDefinition page)
        {
            string fileName = string.Empty;

            if (page.ParentID != 0)
            {
                PageDefinition parent = PageManager.Instance[page.ParentID];

                fileName = GenerateFriendlyFilePathElement(parent)  + GenerateFriendlyName(parent.Title) + "/";
            }
            return fileName;
        }

        private string GenerateFriendlyName(string title)
        {
            List<char> characters = new List<char>(title.ToLower().ToCharArray());

            for (int i = characters.Count - 1; i > -1; i--)
            {
                if (!char.IsLetterOrDigit(characters[i]))
                {
                    if (char.IsWhiteSpace(characters[i]))
                        characters[i] = '-';
                    else
                        characters.RemoveAt(i);
                }
            }
            return new string(characters.ToArray());
        }
    }
}
