/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections;
using System.Collections.Generic;
using System.Configuration;
using System.IO;
using System.Xml;

namespace SheerCMS.Internals
{
    public class PageManager : IEnumerable
    {
        #region Static Code
        private static PageManager i_instance = null;


        static PageManager()
        {
            if (i_instance == null)
            {
                i_instance = new PageManager();
            }
        }


        public static PageManager Instance
        {
            get { return i_instance; }
        }
        #endregion

        #region Private Variables
        private List<PageDefinition> i_rootPages = new List<PageDefinition>();
        private SortedDictionary<int, PageDefinition> i_data = new SortedDictionary<int, PageDefinition>();
        #endregion

        internal PageManager()
        {
            LoadPageMap();
        }

        /// <summary>
        /// 
        /// </summary>
        public int DefaultPageId
        {
            get
            {
                PageDefinition[] rootPages = i_rootPages.ToArray();
                Array.Sort<PageDefinition>(rootPages);
                return rootPages[0].ID;
            }
        }

        /// <summary>
        /// 
        /// </summary>
        public PageDefinition[] RootPages
        {
            get 
            {
                PageDefinition[] rootPages = i_rootPages.ToArray();
                Array.Sort<PageDefinition>(rootPages);
                return rootPages; 
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="pageId"></param>
        /// <returns></returns>
        public PageDefinition[] GetPagePath(int pageId)
        {
            List<PageDefinition> list = new List<PageDefinition>();
            if (i_data.ContainsKey(pageId))
            {
                list.Add(i_data[pageId]);

                while (list[0].ParentID != 0)
                {
                    list.Insert(0, i_data[list[0].ParentID]);
                }
            }

            return list.ToArray();
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public int GetUnassignPageId()
        {
            int i = 1;

            foreach (int key in i_data.Keys)
            {
                if (i != key)
                    break;
                else
                    i++;
            }
            return i;
        }

        /// <summary>
        /// 
        /// </summary>
        public void UpdateContent()
        {
            XmlDocument doc = new XmlDocument();
            doc.Load(ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content.xml");

            File.Move(ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content.xml",
                ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content_"+ 
                DateTime.Now.ToFileTime()+".xml");

            XmlNode node = doc.SelectSingleNode("content/pages");

            if (node != null)
            {
                node.RemoveAll();

                foreach (PageDefinition page in i_data.Values)
                {
                    node.AppendChild(CreateXmlNodeFormPage(page, doc));
                }
            }

            doc.Save(ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content.xml");
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        /// <param name="value"></param>
        public void Add(int key, PageDefinition value)
        {
            i_data.Add(key, value);

            /*if (value.MenuList == 1)
            {
                if (i_data.ContainsKey(value.ParentID))
                    i_data[value.ParentID].AddChild(value);
                else
                    i_rootPages.Add(value);
            }*/
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        public void Remove(int key)
        {
            if (i_data.ContainsKey(key))
            {
                PageDefinition definition = i_data[key];
                i_data.Remove(key);

                if (i_data.ContainsKey(definition.ParentID))
                    i_data[definition.ParentID].RemoveChild(definition);
                else
                    i_rootPages.Remove(definition);
            }
        }

        /// <summary>
        /// 
        /// </summary>
        public int Count
        {
            get { return i_data.Count; }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="key"></param>
        /// <returns></returns>
        public PageDefinition this[int key]
        {
            get
            {
                return i_data[key];
            }
        }

        #region IEnumerable Members
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public IEnumerator GetEnumerator()
        {
            return i_data.Values.GetEnumerator();
        }

        #endregion


        internal void AddPageToRootPageList(PageDefinition page)
        {
            if (!i_rootPages.Contains(page))
                i_rootPages.Add(page);
        }

        internal void RemovePageFromRootPageList(PageDefinition page)
        {
            i_rootPages.Remove(page);
        }

        private void LoadPageMap()
        {
            XmlDocument doc = new XmlDocument();
            doc.Load(ConfigurationManager.AppSettings["CMS_SiteFilePath"] + "Content\\content.xml");

            XmlNodeList nodes = doc.SelectNodes("content/pages/page");
            foreach (XmlNode node in nodes)
            {
                PageDefinition page = new PageDefinition(node);
                i_data.Add(page.ID, page);
            }

            foreach (PageDefinition definition in i_data.Values)
            {
                if (definition.MenuList == 1)
                {
                    if (i_data.ContainsKey(definition.ParentID))
                        i_data[definition.ParentID].AddChild(definition);
                    else
                        i_rootPages.Add(definition);
                }
            }

        }

        private XmlElement CreateXmlNodeFormPage(PageDefinition page, XmlDocument doc)
        {           
            XmlElement node = doc.CreateElement("page");
            XmlAttribute attribute;

            attribute = doc.CreateAttribute("id");
            attribute.InnerText = page.ID.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("parentid");
            attribute.InnerText = page.ParentID.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("title");
            attribute.InnerText = page.Title.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("pageTitle");
            attribute.InnerText = page.PageTitle.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("pageSummary");
            attribute.InnerText = page.PageSummary.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("template");
            attribute.InnerText = page.Template.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("menuOrder");
            attribute.InnerText = page.MenuOrder.ToString();
            node.Attributes.Append(attribute);

            attribute = doc.CreateAttribute("menuList");
            attribute.InnerText = page.MenuList.ToString();
            node.Attributes.Append(attribute);

            node.AppendChild(doc.CreateCDataSection(page.Contents));

            return node;
        }

    }
}
