/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using System.Web.UI.WebControls;
using SheerCMS.Internals;

namespace SheerCMS
{
    /// <summary>
    /// Specifies the layout of the elements of the list items that are displayed.
    /// </summary>
    public enum ItemListLayout
    {
        DateThenDescription,
        DateThenTitle,
        DateThenTitleThenDescription,
        DescriptionOnly,
        DescriptionThenDate,
        TitleThenDate,
        TitleThenDateThenDescription,
        TitleThenDescription,
        TitleThenDescriptionThenDate,
        TitleOnly
    }

    /// <summary>
    /// Specifies the filtering rules for the items in the list.
    /// </summary>
    public enum ItemsFiltering
    {
        DisplayAllItems,
        DisplayFutureItemsOnly,
        DisplayPastItemsOnly
    }

    /// <summary>
    /// Specifies the date order that items in the list are sorted. 
    /// </summary>
    public enum ItemSortOrder
    {
        OlderToYounger,
        YoungerToOlder
    }

    /// <summary>
    /// 
    /// </summary>
    public class ItemListControl : CMSBaseControl
    {
        #region Private Variables
        private int i_listId = 0;
        private int i_numberItemsDisplayed = 5;
        private ItemListLayout i_layout = ItemListLayout.DateThenTitle;
        private ItemsFiltering i_itemsFilter = ItemsFiltering.DisplayAllItems;
        private string i_noItemsMessage = string.Empty;
        private ItemSortOrder i_sortOrder = ItemSortOrder.OlderToYounger;
        #endregion

        #region Public Properties
        /// <summary>
        /// 
        /// </summary>
        public int ListId
        {
            get { return i_listId; }
            set { i_listId = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public int NumberItemsDisplayed
        {
            get { return i_numberItemsDisplayed; }
            set { i_numberItemsDisplayed = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public ItemListLayout Layout
        {
            get { return i_layout; }
            set { i_layout = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public ItemsFiltering ItemsFilter
        {
            get { return i_itemsFilter; }
            set { i_itemsFilter = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public string NoItemsMessage
        {
            get { return i_noItemsMessage; }
            set { i_noItemsMessage = value; }
        }

        /// <summary>
        /// 
        /// </summary>
        public ItemSortOrder SortOrder
        {
            get { return i_sortOrder; }
            set { i_sortOrder = value; }
        }
        #endregion

        #region Public Methods
        /// <summary>
        /// Writes the opening tag of the control to the HTML output stream. 
        /// </summary>
        /// <param name="writer">HTML output stream.</param>
        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("<div id=\"");
            else
                writer.Write("<span id=\"");

            writer.Write(ID);

            writer.Write("\" class=\"item-list");

            if (!(CssClass == string.Empty || CssClass == null))
            {
                writer.Write(" ");
                writer.Write(CssClass);
            }

            if (!(ToolTip == string.Empty || ToolTip == null))
            {
                writer.Write("\" title=\"");
                writer.Write(ToolTip);
            }

            writer.Write("\" >");
        }

        /// <summary>
        /// Writes the ending tag of the control to the HTML output stream.
        /// </summary>
        /// <param name="writer">HTML output stream.</param>
        public override void RenderEndTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("</div>");
            else
                writer.Write("</span>");
        }
        #endregion

        #region Protected Methods
        protected override void RenderContents(HtmlTextWriter writer)
        {
            int i = 0;
            ListEntryManager manager = ListsManager.Instance[i_listId];
            ListEntry[] array = manager.GetListEntries();
            if (i_sortOrder == ItemSortOrder.OlderToYounger)
                Array.Sort(array, new OlderToYoungerItemComparer());
            else
                Array.Sort(array, new YoungerToOlderItemComparer());

            if (manager != null)
            {
                writer.Write("<ul>");
                foreach (ListEntry entry in array)
                {
                    if ((i_itemsFilter == ItemsFiltering.DisplayAllItems ||
                        i_itemsFilter == ItemsFiltering.DisplayFutureItemsOnly && entry.Date > DateTime.Now) ||
                        (i_itemsFilter == ItemsFiltering.DisplayPastItemsOnly && entry.Date < DateTime.Now))
                    {
                        writer.Write("<li class=\"");
                        if (i == 0)
                            writer.Write("start-element ");

                        if (i == manager.Count - 1)
                            writer.Write("end-element ");

                        if (!((i == 0) && (i == manager.Count - 1)))
                            writer.Write("inner-element");

                        writer.Write("\">");

                        /* Add The Date */
                        if (i_layout == ItemListLayout.DateThenDescription
                            || i_layout == ItemListLayout.DateThenTitle
                            || i_layout == ItemListLayout.DateThenTitleThenDescription)
                            AddDateValue(writer, entry);

                        /* Add The Title */
                        if (i_layout != ItemListLayout.DescriptionOnly
                            && i_layout != ItemListLayout.DescriptionThenDate)
                            AddTitleValue(writer, entry);

                        /* Add The Date */
                        if (i_layout == ItemListLayout.TitleThenDateThenDescription)
                            AddDateValue(writer, entry);

                        /* Add The Description */
                        if (i_layout != ItemListLayout.DateThenTitle
                            && i_layout != ItemListLayout.TitleOnly
                            && i_layout != ItemListLayout.TitleThenDate)
                            AddDescriptionValue(writer, entry);

                        /* Add The Date */
                        if (i_layout == ItemListLayout.TitleThenDate
                            || i_layout == ItemListLayout.DescriptionThenDate
                            || i_layout == ItemListLayout.TitleThenDescriptionThenDate)
                            AddDateValue(writer, entry);

                        writer.Write("</li>");
                        i++;

                        if (i_numberItemsDisplayed != -1 && i >= i_numberItemsDisplayed)
                            break;
                    }
                }

                if (i == 0)
                {
                    writer.Write("<li class=\"no-items-message-element\">");
                    writer.Write(i_noItemsMessage);
                    writer.Write("</li>");
                }
                writer.Write("</ul>");
            }
        }
        #endregion

        #region Private Methods
        private void AddDescriptionValue(HtmlTextWriter writer, ListEntry entry)
        {
            writer.Write("<span class=\"list-description\">");
            writer.Write(entry.Contents);
            writer.Write("</span>");
        }

        private void AddTitleValue(HtmlTextWriter writer, ListEntry entry)
        {
            /* Add The Link */
            if (entry.Link != string.Empty)
            {
                writer.Write("<a href=\"");
                writer.Write(entry.Link);
                writer.Write("\" >");
            }

            /* Add The Title */
            writer.Write("<span class=\"list-title\">");
            writer.Write(entry.Title);
            writer.Write("</span>");

            if (entry.Link != string.Empty)
                writer.Write("</a>");
        }

        private void AddDateValue(HtmlTextWriter writer, ListEntry entry)
        {
            writer.Write("<span class=\"list-date\">");
            writer.Write(entry.Date.ToShortDateString());
            writer.Write("</span>");
        }
        #endregion
    }
}
