/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using SheerCMS.Internals;

namespace SheerCMS
{
    public class RSSLinkControl : CMSBaseControl
    {
        private bool i_displayMetaLink = true;
        private bool i_displayHyperLink = true;
        private string i_iconURL = string.Empty;
        private string i_title = string.Empty;
        private int i_listId = 0;

        public bool DisplayMetaLink
        {
            get { return i_displayMetaLink; }
            set { i_displayMetaLink = value; }
        }

        public bool DisplayHyperLink
        {
            get { return i_displayHyperLink; }
            set { i_displayHyperLink = value; }
        }

        public string IconURL
        {
            get { return i_iconURL; }
            set { i_iconURL = value; }
        }

        public int ListId
        {
            get { return i_listId; }
            set { i_listId = value; }
        }

        public string Title
        {
            get { return i_title; }
            set { i_title = value; }
        }


        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            if (i_displayHyperLink)
            {
                if (this.RenderAsDiv)
                    writer.Write("<div id=\"");
                else
                    writer.Write("<span id=\"");

                writer.Write(ID);

                if (!(CssClass == string.Empty || CssClass == null))
                {
                    writer.Write("\" class=\"");
                    writer.Write(CssClass);
                }

                if (!(ToolTip == string.Empty || ToolTip == null))
                {
                    writer.Write("\" title=\"");
                    writer.Write(ToolTip);
                }

                writer.Write("\" >");
            }
        }

        protected override void OnInit(EventArgs e)
        {
            string url = this.Page.Request.Url.AbsoluteUri;

            if (i_displayMetaLink)
            {

                HtmlLink link = new HtmlLink();
                link.Href = url.Substring(0, url.LastIndexOf("/"))+ "/CMS_RSS.aspx?id=" +i_listId.ToString();
                link.Attributes.Add("rel", "alternate");
                link.Attributes.Add("type", "application/rss+xml");

                if (i_title == string.Empty)
                    link.Attributes.Add("title", ListsManager.Instance[i_listId].Title);
                else
                    link.Attributes.Add("title", i_title);

                this.Page.Header.Controls.Add(link);
            }

            if (i_displayHyperLink)
            {
                HtmlAnchor anchor = new HtmlAnchor();
                anchor.HRef = url.Substring(0, url.LastIndexOf("/")) + "/CMS_RSS.aspx?id=" + i_listId.ToString();
                if (i_iconURL == string.Empty)
                {
                    anchor.InnerText = i_title;
                    anchor.Title = i_title;
                }
                else
                {
                    HtmlImage image = new HtmlImage();
                    image.Src = i_iconURL;
                    image.Alt = i_title;
                    anchor.Controls.Add(image);
                }
                this.Controls.Add(anchor);
            }
        }

        public override void RenderEndTag(HtmlTextWriter writer)
        {
            if (i_displayHyperLink)
            {
                if (this.RenderAsDiv)
                    writer.Write("</div>");
                else
                    writer.Write("</span>");
            }
        }
    }
}
