/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Xml;
using System.Xml.XPath;
using SheerCMS.Internals;

namespace SheerCMS
{
    public class SearchControl : CMSBaseControl
    {
        private TextBox i_text = null;
        private Button i_searchButton = null;
        private ImageButton i_imageSearchButton = null;
        private string i_imageButtonURI = string.Empty;

        public string ImageButtonURI
        {
            get { return i_imageButtonURI; }
            set { i_imageButtonURI = value; }
        }

        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("<div id=\"");
            else
                writer.Write("<span id=\"");

            writer.Write(ID);

            if (!(CssClass == string.Empty || CssClass == null))
            {
                writer.Write("\" class=\"");
                writer.Write(CssClass);
            }

            if (!(ToolTip == string.Empty || ToolTip == null))
            {
                writer.Write("\" title=\"");
                writer.Write(ToolTip);
            }

            writer.Write("\" >");
        }


        public override void RenderEndTag(HtmlTextWriter writer)
        {
            if (this.RenderAsDiv)
                writer.Write("</div>");
            else
                writer.Write("</span>");
        }


        protected override void OnInit(EventArgs e)
        {
            i_text = new TextBox();
            i_text.ID = "search_text";
            i_text.CssClass = "search-text";
            this.Controls.Add(i_text);

            if (i_imageButtonURI == string.Empty)
            {
                i_searchButton = new Button();
                i_searchButton.Text = "Search";
                i_searchButton.ToolTip = "Search";
                i_searchButton.ID = "search_button";
                i_searchButton.CssClass = "search-button";
                i_searchButton.Click += new EventHandler(searchButton_Click);
                if (CMSGlobalSettings.FriendlyURL)
                {
                    if (this.Page is CMSBasePage && ((CMSBasePage)this.Page).PageId != -1)
                        i_searchButton.PostBackUrl = PageManager.Instance[((CMSBasePage)this.Page).PageId].FriendlyFileName;
                }
                this.Controls.Add(i_searchButton);
            }
            else
            {
                i_imageSearchButton = new ImageButton();
                i_imageSearchButton.ToolTip = "Search";
                i_imageSearchButton.ImageUrl = this.Page.ResolveUrl(i_imageButtonURI);
                i_imageSearchButton.ID = "search_button";
                i_imageSearchButton.CssClass = "search-button";
                if (CMSGlobalSettings.FriendlyURL)
                {
                    if (this.Page is CMSBasePage && ((CMSBasePage)this.Page).PageId != -1)
                        i_imageSearchButton.PostBackUrl = PageManager.Instance[((CMSBasePage)this.Page).PageId].FriendlyFileName;
                }
                i_imageSearchButton.Click += new ImageClickEventHandler(i_imageSearchButton_Click);
                this.Controls.Add(i_imageSearchButton);
            }

            base.OnInit(e);
        }

        void i_imageSearchButton_Click(object sender, ImageClickEventArgs e)
        {
            Page.Session["SearchString"] = i_text.Text;
            Page.Response.Redirect(this.Page.ResolveUrl("~/CMS_SearchResults.aspx"), true);
        }

        protected void searchButton_Click(object sender, EventArgs e)
        {
            Page.Session["SearchString"] = i_text.Text;
            Page.Response.Redirect(this.Page.ResolveUrl("~/CMS_SearchResults.aspx"), true);

        }
    }
}
