/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using SheerCMS.Internals;

namespace SheerCMS
{
    public class SiteMapControl : CMSBaseControl
    {
        private string i_iconURL = string.Empty;

        /// <summary>
        /// Specifies the URL for the element icons in the sitemap.
        /// </summary>
        public string IconURL
        {
            get { return i_iconURL; }
            set { i_iconURL = value; }
        }


        public override void RenderBeginTag(HtmlTextWriter writer)
        {
            writer.Write("<div id=\"");
            writer.Write(ID);

            if (!(CssClass == string.Empty || CssClass == null))
            {
                writer.Write("\" class=\"");
                writer.Write(CssClass);
            }

            if (!(ToolTip == string.Empty || ToolTip == null))
            {
                writer.Write("\" title=\"");
                writer.Write(ToolTip);
            }

            writer.Write("\" >");
        }

        protected override void RenderContents(HtmlTextWriter writer)
        {
            foreach (PageDefinition page in PageManager.Instance.RootPages)
            {
                RenderSiteMapLevel(writer, page);
            }
        }

        public override void RenderEndTag(HtmlTextWriter writer)
        {
            writer.Write("</div>");
        }


        private void RenderSiteMapLevel(HtmlTextWriter writer, PageDefinition page)
        {
            if (this.RenderAsDiv)
                writer.Write("<div ");
            else
                writer.Write("<span ");

            writer.Write("class=\"pageLevel\">");

            if (i_iconURL != string.Empty)
            {
                writer.Write("<img src=\"");
                writer.Write(i_iconURL);
                writer.Write("\" alt=\"\">");
            }
            writer.Write("<a href=\"");

            if (CMSGlobalSettings.FriendlyURL)
                writer.Write(page.FriendlyFileName);
            else
                writer.Write(this.Page.ResolveUrl("~/"+page.Template+".aspx?id="+page.ID.ToString()));

            writer.Write("\">");
            writer.Write(page.Title);
            writer.Write("</a><br />");

            foreach (PageDefinition childPage in page.Children)
            {
                RenderSiteMapLevel(writer, childPage);
            }

            if (this.RenderAsDiv)
                writer.Write("</div>");
            else
                writer.Write("</span>");
        }
    }
}
