/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using SheerCMS.Internals;

public partial class Administration_ListManagement : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            PopulateListList();
        }
    }

    protected void btn_edit_Click(object sender, EventArgs e)
    {
        if (list_list.SelectedValue != string.Empty)
        {
            selection_panel.Visible = false;
            editor_form.Visible = true;

            PopulateListEditorPanel(ListsManager.Instance[int.Parse(list_list.SelectedValue)]);
        }
    }

    protected void btn_add_Click(object sender, EventArgs e)
    {
        selection_panel.Visible = false;
        editor_form.Visible = true;
        ClearListEditorPanel();
    }

    protected void btn_remove_Click(object sender, EventArgs e)
    {
        if (list_list.SelectedValue != string.Empty)
        {
            lock (ListsManager.Instance)
            {
                ListsManager.Instance.Remove(int.Parse(list_list.SelectedValue));
                ListsManager.Instance.UpdateContent();
            }
            PopulateListList();
        }
    }

    protected void btn_manage_entries_Click(object sender, EventArgs e)
    {
        selection_panel.Visible = false;
        entry_management.Visible = true;

        PopulateEntryManagementPanel(ListsManager.Instance[int.Parse(list_list.SelectedValue)]);
    }


    protected void btn_save_Click(object sender, EventArgs e)
    {
        ListSave();
    }

    protected void btn_save_close_Click(object sender, EventArgs e)
    {
        ListSave();
        list_list.SelectedIndex = -1;
        selection_panel.Visible = true;
        editor_form.Visible = false;
    }

    protected void btn_cancel_Click(object sender, EventArgs e)
    {
        list_list.SelectedIndex = -1;
        selection_panel.Visible = true;
        editor_form.Visible = false;
    }


    protected void btn_add_entry_Click(object sender, EventArgs e) 
    {
        try
        {
            ListEntry newEntry = new ListEntry();
            UpdateListEntry(newEntry);
            ListsManager.Instance[int.Parse(list_list.SelectedValue)].Add(newEntry);
            ListsManager.Instance.UpdateContent();

            ClearEntryManagementPanel();
            PopulateEntryManagementPanel(ListsManager.Instance[int.Parse(list_list.SelectedValue)]);
        }
        catch { }
    }
    
    protected void btn_update_entry_Click(object sender, EventArgs e) 
    {
        try
        {
            if (!string.IsNullOrEmpty(entry_item_list.SelectedValue))
            {
                UpdateListEntry(ListsManager.Instance[int.Parse(list_list.SelectedValue)][int.Parse(entry_item_list.SelectedValue)]);
                ListsManager.Instance.UpdateContent();

                ClearEntryManagementPanel();
                PopulateEntryManagementPanel(ListsManager.Instance[int.Parse(list_list.SelectedValue)]);
            }
        }
        catch { }
    }


    
    protected void btn_remove_entry_Click(object sender, EventArgs e) 
    {
        if (!string.IsNullOrEmpty(entry_item_list.SelectedValue))
        {
            ListsManager.Instance[int.Parse(list_list.SelectedValue)].Remove(int.Parse(entry_item_list.SelectedValue));
            ListsManager.Instance.UpdateContent();

            ClearEntryManagementPanel();
            PopulateEntryManagementPanel(ListsManager.Instance[int.Parse(list_list.SelectedValue)]);
        }
    }


    protected void btn_close_Click(object sender, EventArgs e)
    {
        list_list.SelectedIndex = -1;
        selection_panel.Visible = true;
        entry_management.Visible = false;
    }

    protected void entry_item_list_Changed(object sender, EventArgs e)
    {
        PopulateEntryDetails();
    }


    private void PopulateListEditorPanel(ListEntryManager manager)
    {
        id_textbox.Text = manager.ID.ToString();
        title_textbox.Text = manager.Title;
    }

    private void PopulateEntryDetails()
    {
        ListEntry entry = ListsManager.Instance[int.Parse(list_list.SelectedValue)][int.Parse(entry_item_list.SelectedValue)];
        entry_id_textbox.Text = entry.ID.ToString();
        entry_title_textbox.Text = entry.Title;
        entry_date_textbox.Text = entry.Date.ToShortDateString();
        entry_link_textbox.Text = entry.Link;
        content_editor.Value = entry.Contents;
    }

    private void PopulateListList()
    {
        list_list.Items.Clear();
        foreach (ListEntryManager manager in ListsManager.Instance)
        {
            list_list.Items.Add(new ListItem(manager.Title, manager.ID.ToString()));
        }
    }

    private void PopulateEntryManagementPanel(ListEntryManager listEntryManager)
    {
        entry_item_list.Items.Clear();
        foreach (ListEntry entry in listEntryManager)
        {
            entry_item_list.Items.Add(new ListItem(entry.Date.ToShortDateString()+" - "+entry.Title, entry.ID.ToString()));
        }
    }


    private void ClearEntryManagementPanel()
    {
        entry_item_list.Items.Clear();
        entry_id_textbox.Text = string.Empty;
        entry_title_textbox.Text = string.Empty;
        entry_date_textbox.Text = string.Empty;
        entry_link_textbox.Text = string.Empty;
        content_editor.Value = string.Empty;
    }

    private void ClearListEditorPanel()
    {
        id_textbox.Text = string.Empty;
        title_textbox.Text = string.Empty;
    }


    private void ListSave()
    {
        ListEntryManager manager;

        lock (ListsManager.Instance)
        {
            if (id_textbox.Text == string.Empty)
            {
                manager = new ListEntryManager();
                manager.ID = ListsManager.Instance.GetNextListId();

                ListsManager.Instance.Add(manager.ID, manager);
            }
            else
                manager = ListsManager.Instance[int.Parse(id_textbox.Text)];

            manager.Title = title_textbox.Text;

            ListsManager.Instance.UpdateContent();
        }
        PopulateListList();
    }


    private void UpdateListEntry(ListEntry listEntry)
    {
        listEntry.Date = DateTime.Parse(entry_date_textbox.Text);
        listEntry.Title = entry_title_textbox.Text;
        listEntry.Link = entry_link_textbox.Text;
        listEntry.Contents = content_editor.Value;

    }
}
