/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using SheerCMS.Internals;

public partial class Administration_MenuEditor : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {

        btn_lower_up.Enabled = true;
        btn_lower_down.Enabled = true;

        if (!IsPostBack)
        {
            PopulateMenuTree();
        }
    }

    protected void btn_save_Click(object sender, EventArgs e)
    {
        UpdateMenuOrder(menu_treeview.Nodes[0]);
        PageManager.Instance.UpdateContent();
    }

    protected void btn_make_child_Click(object sender, EventArgs e)
    {
        node_to_move.Value = menu_treeview.SelectedNode.ValuePath;
    }

    protected void btn_up_Click(object sender, EventArgs e)
    {
        TreeNode node = menu_treeview.SelectedNode;
        TreeNode parentNode = node.Parent;
        int index = node.Parent.ChildNodes.IndexOf(node);

        if (index != 0)
        {
            parentNode.ChildNodes.Remove(node);
            parentNode.ChildNodes.AddAt(index - 1, node);
            node.Select();
        }
    }

    protected void btn_down_Click(object sender, EventArgs e)
    {
        TreeNode node = menu_treeview.SelectedNode;
        TreeNode parentNode = node.Parent;
        int index = parentNode.ChildNodes.IndexOf(node);

        if (index != (parentNode.ChildNodes.Count-1))
        {
            parentNode.ChildNodes.Remove(node);
            parentNode.ChildNodes.AddAt(index + 1, node);
            node.Select();
        }
    }

    protected void menu_treeview_SelectedNodeChanged(object sender, EventArgs e)
    {
        int index;
        int nodeCount=1;

        if (menu_treeview.SelectedNode.Parent == null)
            index = 0;
        else
        {
            index = menu_treeview.SelectedNode.Parent.ChildNodes.IndexOf(menu_treeview.SelectedNode);
            nodeCount = menu_treeview.SelectedNode.Parent.ChildNodes.Count;
        }

        if (index == 0)
            btn_lower_up.Enabled = false;

        if (index == (nodeCount - 1))
            btn_lower_down.Enabled = false;

        if (node_to_move.Value != string.Empty)
        {
            TreeNode node = GetNodeToMove();
            node_to_move.Value = string.Empty;

            node.Parent.ChildNodes.Remove(node);
            menu_treeview.SelectedNode.ChildNodes.Add(node);
            node.Select();
        }
    }


    private void UpdateMenuOrder(TreeNode treeNode)
    {
        int i = 1;

        lock (PageManager.Instance)
        {
            foreach (TreeNode node in treeNode.ChildNodes)
            {
                PageDefinition page = PageManager.Instance[int.Parse(node.Value)];
                page.ParentID = int.Parse(treeNode.Value);
                page.MenuOrder = i;
                
                UpdateMenuOrder(node);
                i++;
            }
        }
    }

    private void PopulateMenuTree()
    {
        TreeNode node;
        TreeNode parentNode;

        menu_treeview.Nodes.Clear();
        parentNode = new TreeNode("Site Root", "0");
        menu_treeview.Nodes.Add(parentNode);

        foreach (PageDefinition page in PageManager.Instance.RootPages)
        {
            node = new TreeNode(page.Title, page.ID.ToString());
            parentNode.ChildNodes.Add(node);
            AddNodeToTree(page, node);
        }
    }

    private void AddNodeToTree(PageDefinition parentPage, TreeNode parentNode)
    {
        TreeNode node;

        foreach (PageDefinition page in parentPage.Children)
        {
            node = new TreeNode(page.Title, page.ID.ToString());
            parentNode.ChildNodes.Add(node);
            AddNodeToTree(page, node);
        }
    }

    private TreeNode GetNodeToMove()
    {
        TreeNode node;
        string[] nodePath = node_to_move.Value.Split('/');

        node = menu_treeview.Nodes[0];

        for (int i = 1; i<nodePath.Length; i++)
        {
            foreach (TreeNode child in node.ChildNodes)
            {
                if (child.Value == nodePath[i])
                {
                    node = child;
                    break;
                }
            }
        }
        return node;
        
    }
}
