/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.IO;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using SheerCMS.Internals;

public partial class Administration_PageEditor : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            PopulatePageList();
        }
    }

    protected void btn_edit_Click(object sender, EventArgs e)
    {
        if (page_list.SelectedValue != string.Empty)
        {
            selection_panel.Visible = false;
            editor_form.Visible = true;
            PopulateTemplateList();

            PopulateEditorPanel(PageManager.Instance[int.Parse(page_list.SelectedValue)]);
        }
    }

    protected void btn_add_Click(object sender, EventArgs e)
    {
        selection_panel.Visible = false;
        editor_form.Visible = true;
        ClearEditorPanel();
        PopulateTemplateList();
    }

    protected void btn_remove_Click(object sender, EventArgs e)
    {
        if (page_list.SelectedValue != string.Empty)
        {
            lock (PageManager.Instance)
            {
                PageManager.Instance.Remove(int.Parse(page_list.SelectedValue));
                PageManager.Instance.UpdateContent();
            }
            PopulatePageList();
        }
    }

    protected void btn_save_Click(object sender, EventArgs e)
    {
        if (IsValid)
            PageSave();
    }

    protected void btn_save_close_Click(object sender, EventArgs e)
    {
        if (IsValid)
        {
            PageSave();
            page_list.SelectedIndex = -1;
            selection_panel.Visible = true;
            editor_form.Visible = false;
        }
    }

    protected void btn_preview_Click(object sender, EventArgs e)
    {
        Session["preview"] = content_editor.Value;

        preview_frame.Attributes.Add("src", ResolveUrl("~/" + template_dropdown.SelectedItem.Text + ".aspx?pre=1"));

        editor_form.Visible = false;
        preview_form.Visible = true;
    }

    protected void btn_cancel_Click(object sender, EventArgs e)
    {
        page_list.SelectedIndex = -1;
        selection_panel.Visible = true;
        editor_form.Visible = false;
    }

    protected void btn_preview_cancel_Click(object sender, EventArgs e)
    {
        editor_form.Visible = true;
        preview_form.Visible = false;
    }

    protected void title_custVal_ServerValidate(object source, ServerValidateEventArgs args)
    {
        foreach (PageDefinition page in PageManager.Instance)
        {
            if (page.Title.ToLower() == title_textbox.Text.ToLower() &&
                id_textbox.Text != page.ID.ToString())
            {
                args.IsValid = false;
                break;
            }
        }
    }


    private void PopulatePageList()
    {
        page_list.Items.Clear();
        foreach (PageDefinition page in PageManager.Instance)
        {
            page_list.Items.Add(new ListItem(page.Title, page.ID.ToString()));
        }
    }

    private void PopulateTemplateList()
    {
        string rootPath = Request.MapPath("../");
        DirectoryInfo folder = new DirectoryInfo(rootPath);

        template_dropdown.Items.Clear();

        foreach (FileInfo file in folder.GetFiles("*.aspx"))
        {
            if (!file.Name.StartsWith("CMS_"))
            {
                template_dropdown.Items.Add(file.Name.Replace(file.Extension, string.Empty));
            }
        }
    }

    private void ClearEditorPanel()
    {
        id_textbox.Text = string.Empty;
        pagetitle_textbox.Text = string.Empty;
        title_textbox.Text = string.Empty;
        summary_textbox.Text = string.Empty;
        menuList_checkbox.Checked = false;
        template_dropdown.Items.Clear();
        content_editor.Value = string.Empty;
    }

    private void PopulateEditorPanel(PageDefinition page)
    {
        id_textbox.Text = page.ID.ToString();

        if (CMSGlobalSettings.FriendlyURL)
            url_textbox.Text = page.FriendlyFileName;
        else
            url_textbox.Text = page.Template + ".aspx?id=" + page.ID;

        pagetitle_textbox.Text = page.PageTitle;
        title_textbox.Text = page.Title;
        summary_textbox.Text = page.PageSummary;
        menuList_checkbox.Checked = (page.MenuList == 1);
        template_dropdown.Items.FindByText(page.Template).Selected = true;
        content_editor.Value = page.Contents;
    }

    private void PageSave()
    {
        PageDefinition page;

        lock (PageManager.Instance)
        {
            if (id_textbox.Text == string.Empty)
            {
                page = new PageDefinition();
                page.ID = PageManager.Instance.GetUnassignPageId();

                page.ParentID = 0;

                if (menuList_checkbox.Checked)
                    page.MenuList = 1;
                else
                    page.MenuList = 0;

                PageManager.Instance.Add(page.ID, page);
            }
            else
            {
                page = PageManager.Instance[int.Parse(id_textbox.Text)];
                if (menuList_checkbox.Checked && (page.MenuList == 0))
                {
                    page.MenuList = 1;
                    page.ParentID = 0;
                }
                else if (!menuList_checkbox.Checked && (page.MenuList == 1))
                {
                    page.MenuList = 0;
                    page.ParentID = 0;
                }
            }

            page.PageTitle = pagetitle_textbox.Text;
            page.Title = title_textbox.Text;
            page.PageSummary = summary_textbox.Text;
            page.Template = template_dropdown.SelectedItem.Text;

            page.Contents = content_editor.Value;
            PageManager.Instance.UpdateContent();
        }
        PopulatePageList();
    }
}
