/*
 * SheerCMS version 0.9.0 - January 2008
 *  2006 - 2008 James Hurst, Jim@sheercms.co.uk
 * 
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the Affero General Public License (AGPL) as published by Affero, 
 * Inc. version 1. All files in the SheerCMS distribution are covered by this licence, 
 * except where noted.
 * 
 * IMPORTANT NOTICE: As covered by the AGPL Section 2(d), the "Powered by SheerCMS" 
 * (or similar) link to SheerCMS.co.uk must under no circumstances be removed or 
 * obfuscated in from pages generated by this program. The required link must be 
 * static, visible and readable. This also applies when being used for testing 
 * purposes or on an intranet or internal network.
 * 
 * Please be aware, that the AGPL in Section 2(d) requires, that any modified 
 * version of the program run publicly (ie. on the Internet) must have an additional 
 * download facility for the modified version. This also applies to any modification 
 * of the template.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE. See the AGPL for more details.
 * 
 * A copy of the Affero General Public License is available at SheerCMS.co.uk, 
 * if not, write to Affero, Inc., 510 Third Street, Suite 225, San Francisco, 
 * CA 94107 USA.
 * 
 * This copyright note must under no circumstances be removed from this 
 * file and any distribution of code covered by this licence.
 * 
 * For downloads and information about installation, 
 * please see http://www.sheercms.co.uk/
*/
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using SheerCMS.Internals;

public partial class Administration_SectionEditor : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            PopulateSectionList();
        }
    }

    protected void btn_edit_Click(object sender, EventArgs e)
    {
        if (section_list.SelectedValue != string.Empty)
        {
            selection_panel.Visible = false;
            editor_form.Visible = true;

            PopulateEditorPanel(SectionManager.Instance[int.Parse(section_list.SelectedValue)]);
        }
    }

    protected void btn_add_Click(object sender, EventArgs e)
    {
        selection_panel.Visible = false;
        editor_form.Visible = true;
        ClearEditorPanel();
    }

    protected void btn_remove_Click(object sender, EventArgs e)
    {
        if (section_list.SelectedValue != string.Empty)
        {
            lock (SectionManager.Instance)
            {
                SectionManager.Instance.Remove(int.Parse(section_list.SelectedValue));
                SectionManager.Instance.UpdateContent();
            }
            PopulateSectionList();
        }
    }

    protected void btn_save_Click(object sender, EventArgs e)
    {
        SectionSave();
    }

    protected void btn_save_close_Click(object sender, EventArgs e)
    {
        SectionSave();
        section_list.SelectedIndex = -1;
        selection_panel.Visible = true;
        editor_form.Visible = false;
    }

    protected void btn_cancel_Click(object sender, EventArgs e)
    {
        section_list.SelectedIndex = -1;
        selection_panel.Visible = true;
        editor_form.Visible = false;
    }


    private void PopulateSectionList()
    {
        section_list.Items.Clear();
        foreach (SectionDefinition section in SectionManager.Instance)
        {
            section_list.Items.Add(new ListItem(section.Title, section.ID.ToString()));
        }
    }

    private void ClearEditorPanel()
    {
        id_textbox.Text = string.Empty;
        title_textbox.Text = string.Empty;
        content_editor.Value = string.Empty;
    }

    private void PopulateEditorPanel(SectionDefinition section)
    {
        id_textbox.Text = section.ID.ToString();
        title_textbox.Text = section.Title;
        content_editor.Value = section.Contents;
    }

    private void SectionSave()
    {
        SectionDefinition section;

        lock (SectionManager.Instance)
        {
            if (id_textbox.Text == string.Empty)
            {
                section = new SectionDefinition();
                section.ID = SectionManager.Instance.GetUnassignSectionId();

                SectionManager.Instance.Add(section.ID, section);
            }
            else
                section = SectionManager.Instance[int.Parse(id_textbox.Text)];

            section.Title = title_textbox.Text;

            section.Contents = content_editor.Value;
            SectionManager.Instance.UpdateContent();
        }
        PopulateSectionList();
    }
}
